netapp_ontap.resources.ldap_schema API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.ldap_schema`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

ONTAP provides four default LDAP schemas. These are:

- MS-AD-BIS Based on RFC-2307bis. This is the preferred LDAP schema for most standard Windows 2012 and later LDAP deployments.

- AD-IDMU Based on Active Directory Identity Management for UNIX. This schema is appropriate for most Windows 2008, Windows 2012, and later AD servers.

- AD-SFU Based on Active Directory Services for UNIX. This schema is appropriate for most Windows 2003 and earlier AD servers.

- RFC-2307 Based on RFC-2307 (an approach that uses LDAP as a network information service). This schema is appropriate for most UNIX AD servers.

## Examples

### Retrieving LDAP schema information

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LdapSchema

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(LdapSchema.get_collection()))

Try it out

    [
        LdapSchema(
            {
                "_links": {
                    "self": {
                        "href": "/api/name-services/ldap-schemas/eda950c6-0a0c-11ec-bfcf-0050568e9150/AD-IDMU"
                    }
                },
                "name": "AD-IDMU",
                "owner": {
                    "name": "athiraacluster-1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/eda950c6-0a0c-11ec-bfcf-0050568e9150"
                        }
                    },
                    "uuid": "eda950c6-0a0c-11ec-bfcf-0050568e9150",
                },
            }
        ),
        LdapSchema(
            {
                "_links": {
                    "self": {
                        "href": "/api/name-services/ldap-schemas/eda950c6-0a0c-11ec-bfcf-0050568e9150/AD-SFU"
                    }
                },
                "name": "AD-SFU",
                "owner": {
                    "name": "athiraacluster-1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/eda950c6-0a0c-11ec-bfcf-0050568e9150"
                        }
                    },
                    "uuid": "eda950c6-0a0c-11ec-bfcf-0050568e9150",
                },
            }
        ),
        LdapSchema(
            {
                "_links": {
                    "self": {
                        "href": "/api/name-services/ldap-schemas/eda950c6-0a0c-11ec-bfcf-0050568e9150/MS-AD-BIS"
                    }
                },
                "name": "MS-AD-BIS",
                "owner": {
                    "name": "athiraacluster-1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/eda950c6-0a0c-11ec-bfcf-0050568e9150"
                        }
                    },
                    "uuid": "eda950c6-0a0c-11ec-bfcf-0050568e9150",
                },
            }
        ),
        LdapSchema(
            {
                "_links": {
                    "self": {
                        "href": "/api/name-services/ldap-schemas/eda950c6-0a0c-11ec-bfcf-0050568e9150/RFC-2307"
                    }
                },
                "name": "RFC-2307",
                "owner": {
                    "name": "athiraacluster-1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/eda950c6-0a0c-11ec-bfcf-0050568e9150"
                        }
                    },
                    "uuid": "eda950c6-0a0c-11ec-bfcf-0050568e9150",
                },
            }
        ),
    ]

### Retrieving LDAP schema information for a given SVM and "name"

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LdapSchema

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LdapSchema(
            name="RFC-2307", **{"owner.uuid": "eda950c6-0a0c-11ec-bfcf-0050568e9150"}
        )
        resource.get()
        print(resource)

Try it out

    LdapSchema(
        {
            "_links": {
                "self": {
                    "href": "/api/name-services/ldap-schemas/eda950c6-0a0c-11ec-bfcf-0050568e9150/RFC-2307"
                }
            },
            "rfc2307bis": {
                "maximum_groups": 256,
                "group_of_unique_names": "groupOfUniqueNames",
                "unique_member": "uniqueMember",
                "enabled": False,
            },
            "name": "RFC-2307",
            "global_schema": True,
            "comment": "Schema based on RFC 2307 (read-only)",
            "name_mapping": {
                "account": {"windows": "windowsAccount", "unix": "unixAccount"},
                "windows_to_unix": {
                    "object_class": "posixAccount",
                    "no_domain_prefix": False,
                    "attribute": "windowsAccount",
                },
            },
            "owner": {
                "name": "svm1",
                "_links": {
                    "self": {"href": "/api/svm/svms/eda950c6-0a0c-11ec-bfcf-0050568e9150"}
                },
                "uuid": "eda950c6-0a0c-11ec-bfcf-0050568e9150",
            },
            "rfc2307": {
                "posix": {"account": "posixAccount", "group": "posixGroup"},
                "member": {"uid": "memberUid", "nis_netgroup": "memberNisNetgroup"},
                "cn": {"netgroup": "cn", "group": "cn"},
                "attribute": {
                    "login_shell": "loginShell",
                    "gecos": "gecos",
                    "home_directory": "homeDirectory",
                    "gid_number": "gidNumber",
                    "user_password": "userPassword",
                    "uid_number": "uidNumber",
                    "uid": "uid",
                },
                "nis": {
                    "netgroup": "nisNetgroup",
                    "mapentry": "nisMapEntry",
                    "object": "nisObject",
                    "mapname": "nisMapName",
                    "netgroup_triple": "nisNetgroupTriple",
                },
            },
            "scope": "cluster",
        }
    )

### Creating an LDAP schema

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LdapSchema

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LdapSchema()
        resource.name = "schema"
        resource.template = {"name": "AD-IDMU"}
        resource.owner = {"uuid": "52ba8197-0a23-11ec-9622-0050568e9150", "name": "svm1"}
        resource.post(hydrate=True)
        print(resource)

### Updating an LDAP schema

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LdapSchema

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LdapSchema(
            name="schema", **{"owner.uuid": "52ba8197-0a23-11ec-9622-0050568e9150"}
        )
        resource.comment = "This is a comment for schema"
        resource.patch()

### Deleting an LDAP schema

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LdapSchema

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LdapSchema(
            name="schema", **{"owner.uuid": "52ba8197-0a23-11ec-9622-0050568e9150"}
        )
        resource.delete()

## Classes

`class LdapSchema (*args, **kwargs)`

  Allows interaction with LdapSchema objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all LdapSchema resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('LdapSchema')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an existing schema.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema delete`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent LdapSchema resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves all the LDAP schemas.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema show`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves all the LDAP schemas.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema show`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('LdapSchema')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates LDAP schema details for a given owner and schema.

    ### Important notes

    - The default LDAP schemas provided by ONTAP cannot be modified.
    - LDAP schemas can only be modified by the owner of the schema.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema modify`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('LdapSchema')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[LdapSchema], NetAppResponse]`

    Creates an LDAP schema.

    ### Important notes

    - To create a new schema, first create a copy of the default schemas provided by ONTAP and then modify the copy accordingly.
    - If no value is specified for the owner.uuid or owner.name fields, the cserver UUID and name are used by default.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema copy`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes an existing schema.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema delete`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves LDAP schema details for a given owner and schema.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema show`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates LDAP schema details for a given owner and schema.

    ### Important notes

    - The default LDAP schemas provided by ONTAP cannot be modified.
    - LDAP schemas can only be modified by the owner of the schema.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema modify`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates an LDAP schema.

    ### Important notes

    - To create a new schema, first create a copy of the default schemas provided by ONTAP and then modify the copy accordingly.
    - If no value is specified for the owner.uuid or owner.name fields, the cserver UUID and name are used by default.

    ### Related ONTAP commands

    - `vserver services name-service ldap client schema copy`

    ### Learn more

    - `DOC /name-services/ldap-schemas`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class LdapSchemaSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LdapSchema object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str GET PATCH`

    Comment to associate with the schema.

    Example: Schema based on Active Directory Services for UNIX (read-only).

  `global_schema: bool GET`

    A global schema that can be used by all the SVMs.

    Example: true

  `links: SelfLink GET`

    The links field of the ldap_schema.

  `name: str GET POST`

    The name of the schema being created, modified or deleted.

    Example: AD-SFU-v1

  `name_mapping: LdapNameMapping GET PATCH`

    The name_mapping field of the ldap_schema.

  `owner: Svm GET POST`

    The owner field of the ldap_schema.

  `rfc2307: Rfc2307 GET PATCH`

    The rfc2307 field of the ldap_schema.

  `rfc2307bis: Rfc2307bis GET PATCH`

    The rfc2307bis field of the ldap_schema.

  `scope: str GET`

    Scope of the entity. Set to "cluster" for cluster owned objects and to "svm" for SVM owned objects.

    Valid choices:

    - cluster
    - svm
  `template: Ldap POST`

    The template field of the ldap_schema.